@@ -2,6 +2,7 @@
 package Mail::Builder::Attachment;
 # ============================================================================
 
+use namespace::autoclean;
 use Moose;
 with qw(Mail::Builder::Role::File);
 use Mail::Builder::TypeConstraints;
@@ -126,7 +127,6 @@ sub serialize {
     return $entity;
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
