@@ -2,6 +2,7 @@
 package Mail::Builder::Attachment::Data;
 # ============================================================================
 
+use namespace::autoclean;
 use Moose;
 extends qw(Mail::Builder::Attachment);
 
@@ -13,7 +14,6 @@ before BUILDARGS => sub{
     carp '<Mail::Builder::Attachment::File> is deprecated, use <Mail::Builder::Attachment> instead';
 };
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
