@@ -2,6 +2,7 @@
 package Mail::Builder::List;
 # ============================================================================
 
+use namespace::autoclean;
 use Moose;
 use Mail::Builder::TypeConstraints;
 
@@ -222,7 +223,6 @@ sub item {
 #    return $obj;
 #}
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
